pub async fn connect_execution_peers<TClock: Clock>(
nodes: &[TestingNode<TClock>],
)Expand description
Connects all running execution nodes as peers.
This must be called after nodes are started so that the ports are known
pub async fn connect_execution_peers<TClock: Clock>(
nodes: &[TestingNode<TClock>],
)Connects all running execution nodes as peers.
This must be called after nodes are started so that the ports are known