connect_execution_to_peers

Function connect_execution_to_peers 

pub async fn connect_execution_to_peers<TClock: Clock>(
    node: &TestingNode<TClock>,
    nodes: &[TestingNode<TClock>],
)
Connects a running node to a set of peers

Useful when a node is restarted and needs to re-connect to its previous peers as ports are not statically defined.