pub async fn link_validators<TClock: Clock>(
oracle: &mut Oracle<PublicKey, TClock>,
validators: &[TestingNode<TClock>],
link: Link,
restrict_to: Option<fn(usize, usize, usize) -> bool>,
)Expand description
Links (or unlinks) validators using the oracle.
The restrict_to function can be used to restrict the linking to certain connections,
otherwise all validators will be linked to all other validators.